from flask import Flask, render_template, request, redirect, flash
from werkzeug.utils import secure_filename
import os

app = Flask(__name__)
app.secret_key = 'some_secret_key'
app.config['UPLOAD_DIRECTORY'] = 'uploads/'
app.config['MAX_CONTENT_LENGTH'] = 16 * 1024 * 1024 * 1024
app.config['ALLOWED_EXTENSIONS'] = ['.txt', '.py', '.word']

@app.route('/')
def index():
    return render_template('index.html')

@app.route('/upload', methods = ['POST'])
def upload():
    file = request.files['file']
    extension = os.path.splitext(file.filename)[1].lower()

    if file:
      
      if extension not in app.config['ALLOWED_EXTENSIONS']:
          flash("Please upload word file or py file")
      else:
        file.save(os.path.join(app.config['UPLOAD_DIRECTORY'], secure_filename(file.filename)))

    return redirect('/')

@app.route('/analyze', methods = ['GET'])
def analyze():
    file_list = os.listdir(app.config['UPLOAD_DIRECTORY'])
    contents = []

    for file_name in file_list:
        with open(os.path.join(app.config['UPLOAD_DIRECTORY'], file_name), 'r') as file:
            content = file.read()
            words = content.split()
            word_counts = {}
            for word in words:
                if word not in word_counts:
                    word_counts[word] = 1
                else:
                    word_counts[word] += 1
            contents.append((file_name, word_counts))

    return render_template('analyze.html', contents=contents)


if __name__ == '__main__':
    app.run(debug=True)